Skip to contents

A sf object containing polygons representing the border of each county of Missouri. The boundary was derived by dissolving the county boundaries from the tigris, county data layer. It is in NAD83 UTM 15N (meters) coordinate system. Per the tigris package, it is 1:500k resolution (default)

Usage

counties.mo

Format

An object of class sf (inherits from data.frame) with 115 rows and 7 columns.

Examples

if (FALSE) { # \dontrun{
tigris::counties(state='MO')%>%
sf::st_transform(., crs=26915)%>% # reproject to NAD83 UTM 15N
 select(STATEFP,
        COUNTYFP,GEOID,
        NAME,
        NAMELSAD,
        LSAD)->counties.mo
} # }