A sf object containing polygons representing the border of each county of Missouri. The boundary was derived by dissolving the county boundaries from the tigris, county data layer. It is in NAD83 UTM 15N (meters) coordinate system. Per the tigris package, it is 1:500k resolution (default)
Examples
if (FALSE) { # \dontrun{
tigris::counties(state='MO')%>%
sf::st_transform(., crs=26915)%>% # reproject to NAD83 UTM 15N
select(STATEFP,
COUNTYFP,GEOID,
NAME,
NAMELSAD,
LSAD)->counties.mo
} # }